@@ -1,9 +1,12 @@
 package LWP::Protocol::loopback;
-$LWP::Protocol::loopback::VERSION = '6.27';
+
 use strict;
+
+our $VERSION = '6.68';
+
 require HTTP::Response;
 
-use base qw(LWP::Protocol);
+use parent qw(LWP::Protocol);
 
 sub request {
     my($self, $request, $proxy, $arg, $size, $timeout) = @_;
